@@ -26,7 +26,7 @@
 #include <kio/global.h>
 #include <kurlrequester.h>
 
-#include <diffsettings.h>
+#include <libkomparediff2/diffsettings.h>
 
 KompareSaveOptionsWidget::KompareSaveOptionsWidget( QString source, QString destination,
            DiffSettings * settings, QWidget * parent )
@@ -221,5 +221,3 @@ void KompareSaveOptionsWidget::saveOptions()
 	m_settings->m_format = static_cast<Kompare::Format>( m_FormatBG->checkedId() );
 
 }
-
-#include "komparesaveoptionswidget.moc"
